<?php
/*
Plugin Name: Custom Headers and Footers
Plugin URI: http://www.poradnik-webmastera.com/projekty/custom_headers_and_footers/
Description: This plugin adds custom header and footer for main page content.
Author: Daniel Frużyński
Version: 1.0.4
Author URI: http://www.poradnik-webmastera.com/
Text Domain: custom-headers-and-footers
*/

/*  Copyright 2009  Daniel Frużyński  (email : daniel [A-T] poradnik-webmastera.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

if ( !class_exists( 'CustomHeadersAndFooters' ) ) {

class CustomHeadersAndFooters {
	// Constructor
	function CustomHeadersAndFooters() {
		// Initialise plugin
		add_action( 'init', array( &$this, 'init' ) );
		add_action( 'admin_init', array( &$this, 'admin_init' ) );
		
		add_action( 'admin_menu', array( &$this, 'admin_menu' ) );
		
		add_action( 'loop_start', array( &$this, 'loop_start' ) );
		add_action( 'loop_end', array( &$this, 'loop_end' ) );
	}
	
	// Initialise plugin
	function init() {
		if ( function_exists( 'load_plugin_textdomain' ) ) {
			load_plugin_textdomain( 'custom-headers-and-footers', PLUGINDIR.'/'.dirname(plugin_basename(__FILE__)) );
		}
	}
	
	// Initialise plugin - admin part
	function admin_init() {
		register_setting( 'custom-headers-and-footers', 'chaf_header', 'trim' );
		register_setting( 'custom-headers-and-footers', 'chaf_footer', 'trim' );
	}
	
	// Add Admin menu option
	function admin_menu() {
		$file = __FILE__;
		
		add_submenu_page( 'options-general.php', 'Custom Headers and Footers', 
			'Custom Headers and Footers', 10, $file, array( $this, 'options_panel' ) );
	}
	
	// Display header
	function loop_start( &$wp_query ) {
		global $wp_the_query;
		if ( ( $wp_query === $wp_the_query ) && !is_admin() ) {
			echo get_option( 'chaf_header' );
		}
	}
	
	// Display footer
	function loop_end( &$wp_query ) {
		global $wp_the_query;
		if ( ( $wp_query === $wp_the_query ) && !is_admin() ) {
			echo get_option( 'chaf_footer' );
		}
	}
	
	// Handle options panel
	function options_panel() {
			$message = null;
			if ( isset($_POST['action']) ) {
				check_admin_referer( 'wypiekacz-options' );
				$message = __('Configuration has been saved.', 'wypiekacz');
				echo '<div id="message" class="updated fade"><p>', $message, '</p></div>', "\n";
			}
?>
<div id="dropmessage" class="updated" style="display:none;"></div>
<div class="wrap">
<h2><?php _e('Custom Headers and Footers - Options', 'custom-headers-and-footers'); ?></h2>

<form name="dofollow" action="options.php" method="post">
<?php settings_fields( 'custom-headers-and-footers' ); ?>
<table class="form-table">

<tr>
<th scope="row" style="text-align:right; vertical-align:top;">
<label for="chaf_header"><?php _e('Header:', 'custom-headers-and-footers'); ?></label>
</th>
<td>
<textarea rows="5" cols="57" id="chaf_header" name="chaf_header"><?php echo htmlspecialchars( stripcslashes( get_option( 'chaf_header' ) ) ); ?></textarea>
</td>
</tr>

<tr>
<th scope="row" style="text-align:right; vertical-align:top;">
<label for="chaf_footer"><?php _e('Footer:', 'custom-headers-and-footers'); ?></label>
</th>
<td>
<textarea rows="5" cols="57" id="chaf_footer" name="chaf_footer"><?php echo htmlspecialchars( stripcslashes( get_option( 'chaf_footer' ) ) ); ?></textarea>
</td>
</tr>

</table>

<p class="submit">
<input type="hidden" name="action" value="update" />
<input type="submit" name="Submit" value="<?php _e('Save settings', 'custom-headers-and-footers'); ?>" /> 
</p>

</form>
</div>
<?php
	}
}

add_option( 'chaf_header', '' );
add_option( 'chaf_footer', '' );

$wp_custom_headers_and_footers = new CustomHeadersAndFooters();

} /* END */

?>